/*!
    \file    interrupt_test.h
    \brief   the header file of interrupt test

*/

#ifndef INTERRUPT_TEST_H
#define INTERRUPT_TEST_H

/* interrupt test */
void interrupt_test(void);
void uart1_irq_handle(void);
void timer0_irq_handle(void);
void timer1_irq_handle(void);
void timer2_irq_handle(void);
void i2c0_irq_handle(void);
void i2c1_irq_handle(void);
void i2c2_irq_handle(void);
void wdt_irq_handle(void);
void gpioa_irq_handle(void);
void gpiob_irq_handle(void);
void qspi_irq_handle(void);
void spi_mst_irq_handle(void);
void spi_slv_irq_handle(void);
void rtc_irq_handle(void);

#endif  /* INTERRUPT_TEST_H */
